/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/m-cen-lx-xr-ntly-0000000000000/build/dom/interfaces/base/nsIDOMSpeechSynthesisGetter.idl
 */

#ifndef __gen_nsIDOMSpeechSynthesisGetter_h__
#define __gen_nsIDOMSpeechSynthesisGetter_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSpeechSynthesisGetter */
#define NS_IDOMSPEECHSYNTHESISGETTER_IID_STR "9fe60496-8356-430e-bf38-2debec45711e"

#define NS_IDOMSPEECHSYNTHESISGETTER_IID \
  {0x9fe60496, 0x8356, 0x430e, \
    { 0xbf, 0x38, 0x2d, 0xeb, 0xec, 0x45, 0x71, 0x1e }}

class NS_NO_VTABLE nsIDOMSpeechSynthesisGetter : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSPEECHSYNTHESISGETTER_IID)

  /* readonly attribute nsISupports speechSynthesis; */
  NS_IMETHOD GetSpeechSynthesis(nsISupports * *aSpeechSynthesis) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSpeechSynthesisGetter, NS_IDOMSPEECHSYNTHESISGETTER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSPEECHSYNTHESISGETTER \
  NS_IMETHOD GetSpeechSynthesis(nsISupports * *aSpeechSynthesis); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSPEECHSYNTHESISGETTER(_to) \
  NS_IMETHOD GetSpeechSynthesis(nsISupports * *aSpeechSynthesis) { return _to GetSpeechSynthesis(aSpeechSynthesis); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSPEECHSYNTHESISGETTER(_to) \
  NS_IMETHOD GetSpeechSynthesis(nsISupports * *aSpeechSynthesis) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSpeechSynthesis(aSpeechSynthesis); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSpeechSynthesisGetter : public nsIDOMSpeechSynthesisGetter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSPEECHSYNTHESISGETTER

  nsDOMSpeechSynthesisGetter();

private:
  ~nsDOMSpeechSynthesisGetter();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSpeechSynthesisGetter, nsIDOMSpeechSynthesisGetter)

nsDOMSpeechSynthesisGetter::nsDOMSpeechSynthesisGetter()
{
  /* member initializers and constructor code */
}

nsDOMSpeechSynthesisGetter::~nsDOMSpeechSynthesisGetter()
{
  /* destructor code */
}

/* readonly attribute nsISupports speechSynthesis; */
NS_IMETHODIMP nsDOMSpeechSynthesisGetter::GetSpeechSynthesis(nsISupports * *aSpeechSynthesis)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSpeechSynthesisGetter_h__ */
